{% extends "base.html" %}

{% block title %}
    Home
{% endblock %}

{% block content %}
    <div class="dbox">
        <div class="dbox-top">
            <span class="left">Under construction</span>
        </div>
        <div class="dbox-bot">
            <p>
                Lentamente, su questo sito stanno apparendo nuove features. Come il <a href="{{ url_for("diarioview.diarioview_page", page=1) }}">diario</a> e i <a href="{{ url_for("profile.profile_index") }}">profili</a>!
            </p>
        </div>
    </div>
{% endblock %}