{% extends "base.html" %}

{% block title %}
    Elenco profili
{% endblock %}

{% block content %}
    <div class="dbox">
        <div class="dbox-top">
            <span class="left">
                Elenco profili
            </span>
        </div>
        <div class="dbox-bot">
            <ul>
                {% for royal in royals %}
                    <li><a href="{{ url_for("profile.profile_by_username", username=royal.username) }}">{{ royal.username }}</a></li>
                {% endfor %}
            </ul>
        </div>
    </div>
{% endblock %}
